Glossary
--------

.. glossary::
    Brittle Code
      Code that works when the input data is in a particular format but is prone to breakage if there is some deviation from the correct format. We call this "brittle code" because it is easily broken.

    Greedy Matching
      The notion that the ``+`` and ``*`` characters in a regular expression expand outward to match the largest possible string.

    Grep
      A command available in most Unix systems that searches through text files looking for lines that match regular expressions. The command name stands for "Generalized Regular Expression Parser".

    Regular Expression
      A language for expressing more complex search strings. A regular expression may contain special characters that indicate that a search only matches at the beginning or end of a line or many other similar capabilities.

    Wild Card
      A special character that matches any character. In regular expressions the wild-card character is the period.

.. dragndrop:: chapter_11_glossary_one
    :feedback: Look above for the definitions of these terms.
    :match_1: brittle code|||Code that works when the input data is in a particular format but is prone to breakage if there is some deviation from the correct format. 
    :match_2: greedy matching|||The notion that the ``+`` and ``*`` characters in a regular expression expand outward to match the largest possible string.
    :match_3: grep|||A command available in most Unix systems that searches through text files looking for lines that match regular expressions.
    :match_4: regular expression|||A language for expressing more complex search strings.
    :match_5: wild card|||A special character that matches any character.

    Match the following terms with their definitions.
